@@ -28,6 +28,8 @@ import zc.buildout
 from slapos.recipe.librecipe import wrap
 from slapos.recipe.librecipe import GenericSlapRecipe
 
+CONNECTION_PARAMETER_STRING = 'connection-'
+
 class Recipe(GenericSlapRecipe):
   def _install(self):
     publish_dict = dict()
@@ -47,3 +49,26 @@ SERIALISED_MAGIC_KEY = '_'
 class Serialised(Recipe):
   def _setConnectionDict(self, publish_dict):
     return super(Serialised, self)._setConnectionDict(wrap(publish_dict))
+
+
+
+class PublishSection(GenericSlapRecipe):
+  """
+  Take a list of "request" sections, and publish every connection parameter.
+  
+  Input:
+    section-list: String, representing the list of sections to fetch
+                  parameters to publish, in order, separated by a space.
+  """
+  def _install(self):
+    publish_dict = dict()
+    for section in self.options['section-list'].strip().split():
+      section = section.strip()
+      options = self.buildout[section].copy()
+      for k, v in options.iteritems():
+        if k.startswith(CONNECTION_PARAMETER_STRING):
+          print k, v
+          publish_dict[k.lstrip(CONNECTION_PARAMETER_STRING)] = v
+    self.setConnectionDict(publish_dict)
+    return []
+
